@@ -188,10 +188,7 @@ static void
 PGrnHighlightHTMLSetLexicon(const char *indexName)
 {
 	Oid oid;
-	grn_obj *tokenizer = NULL;
-	grn_obj *normalizers = NULL;
-	grn_obj *tokenFilters = NULL;
-	grn_table_flags flags = 0;
+	Relation index;
 
 	if (!indexName || indexName[0] == '\0')
 	{
@@ -211,31 +208,15 @@ PGrnHighlightHTMLSetLexicon(const char *indexName)
 		return;
 	}
 
-	{
-		Relation index = PGrnPGResolveIndexName(indexName);
-		PGrnApplyOptionValues(index,
-							  -1,
-							  PGRN_OPTION_USE_CASE_FULL_TEXT_SEARCH,
-							  &tokenizer, PGRN_DEFAULT_TOKENIZER,
-							  &normalizers, PGRN_DEFAULT_NORMALIZERS,
-							  &tokenFilters,
-							  &flags,
-							  NULL);
-		RelationClose(index);
-	}
-
+	index = PGrnPGResolveIndexName(indexName);
 	if (lexicon)
 	{
 		grn_highlighter_set_lexicon(ctx, highlighter, NULL);
 		grn_obj_close(ctx, lexicon);
 	}
-	lexicon = PGrnCreateTable(InvalidRelation,
-							  NULL,
-							  flags,
-							  grn_ctx_at(ctx, GRN_DB_SHORT_TEXT),
-							  tokenizer,
-							  normalizers,
-							  tokenFilters);
+	lexicon = PGrnCreateSimilarTemporaryLexicon(index);
+	RelationClose(index);
+
 	grn_highlighter_set_lexicon(ctx, highlighter, lexicon);
 	PGrnCheck("highlight-html: failed to set lexicon");
 	indexOID = oid;
